@@ -1,25 +1,11 @@
-use warnings;
 use strict;
+use warnings;
 package Religion::Bible::Reference::Standard;
+{
+  $Religion::Bible::Reference::Standard::VERSION = '0.015';
+}
+# ABSTRACT: standard bible books and abbreviations
 
-=head1 NAME
-
-Religion::Bible::Reference::Standard - standard bible books and abbreviations
-
-=head1 VERSION
-
-version 0.012
-
-=cut
-
-our $VERSION = '0.012';
-
-=head1 DESCRIPTION
-
-This module is a package of book descriptions and abbreviations for use with
-Religion::Bible::Reference.  It is loaded by that module by default.
-
-=cut
 
 my @books = (
   'Genesis' => {
@@ -439,23 +425,34 @@ sub _books {
   return @_books;
 }
 
+1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Religion::Bible::Reference::Standard - standard bible books and abbreviations
+
+=head1 VERSION
+
+version 0.015
+
+=head1 DESCRIPTION
+
+This module is a package of book descriptions and abbreviations for use with
+Religion::Bible::Reference.  It is loaded by that module by default.
+
 =head1 AUTHOR
 
-Ricardo Signes, C<< <rjbs@cpan.org> >>
+Ricardo SIGNES <rjbs@cpan.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.  I will be notified, and then you'll automatically be
-notified of progress on your bug as I make changes.
+This software is copyright (c) 2005 by Ricardo SIGNES.
 
-=head1 COPYRIGHT
-
-Copyright 2005 Ricardo Signes, All Rights Reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
